# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""SSA-6391: add test_download capability and workflow

Revision ID: e50583fc2a8e
Revises: 21dc67216082
Create Date: 2021-01-20 14:26:21.397835

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "e50583fc2a8e"
down_revision = "ec2aab4ad517"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        "INSERT INTO capabilities (capability_name, capability_steps, max_jobs) "
        "VALUES ('test_download', 'prepare-and-run-workflow deliver [-r, -l]\nawait-workflow', 2)"
    )
    op.execute("INSERT INTO workflows (workflow_name) VALUES ('test_download')")
    op.execute(
        "INSERT INTO workflow_templates (workflow_name, filename, content) "
        "VALUES ('test_download', 'test_download.condor', E'executable = test_download.sh\narguments = {{arguments}}"
        "\nerror = test_download.err\nlog = test_download.log\n\n\nqueue')"
    )
    op.execute(
        "INSERT INTO workflow_templates (workflow_name, filename, content) VALUES "
        "('test_download', 'test_download.sh', E'#!/bin/sh\n\ndatafetcher --product-locator $1\ndeliver -r .\n')"
    )
    op.execute(
        "INSERT INTO workflow_templates (Workflow_name, filename, content)"
        "VALUES ('test_download', 'test_download.dag', E'JOB test_download test_download.condor')"
    )


def downgrade():
    op.execute("DELETE FROM capabilities WHERE capability_name = 'test_download'")
    op.execute("DELETE FROM workflows WHERE workflow_name = 'test_download'")
    op.execute("DELETE FROM workflow_templates WHERE workflow_name = 'test_download'")
